"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.configSet = configSet;
const path_1 = __importDefault(require("path"));
const util_1 = __importDefault(require("util"));
const run_npm_1 = require("@pnpm/run-npm");
const read_ini_file_1 = require("read-ini-file");
const write_ini_file_1 = require("write-ini-file");
async function configSet(opts, key, value) {
    const configPath = opts.global ? path_1.default.join(opts.configDir, 'rc') : path_1.default.join(opts.dir, '.npmrc');
    if (opts.global && settingShouldFallBackToNpm(key)) {
        const _runNpm = run_npm_1.runNpm.bind(null, opts.npmPath);
        if (value == null) {
            _runNpm(['config', 'delete', key]);
        }
        else {
            _runNpm(['config', 'set', `${key}=${value}`]);
        }
        return;
    }
    const settings = await safeReadIniFile(configPath);
    if (value == null) {
        if (settings[key] == null)
            return;
        delete settings[key];
    }
    else {
        settings[key] = value;
    }
    await (0, write_ini_file_1.writeIniFile)(configPath, settings);
}
function settingShouldFallBackToNpm(key) {
    return (['registry', '_auth', '_authToken', 'username', '_password'].includes(key) ||
        key[0] === '@' ||
        key.startsWith('//'));
}
async function safeReadIniFile(configPath) {
    try {
        return await (0, read_ini_file_1.readIniFile)(configPath);
    }
    catch (err) {
        if (util_1.default.types.isNativeError(err) && 'code' in err && err.code === 'ENOENT')
            return {};
        throw err;
    }
}
//# sourceMappingURL=configSet.js.map